# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class WorkflowVersionSummaryParams(typing_extensions.TypedDict):
    object: typing.Literal["workflow_version"]
    """
    The type of object. In this case, it will always be `"workflow_version"`.
    """

    id: str
    """
    The ID of the workflow version.
    
    Example: `"workflow_version_Zk9mNP12Qw4-yTv8BdR3H"`
    """

    version: str
    """
    The version of the workflow version.
    
    Example: `"3"`
    """

    name: typing.Optional[str]
    """
    The name of the workflow version.
    
    Example: `"Invoice Processing"`
    """
