# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.created_at import CreatedAt
from ..types.updated_at import UpdatedAt


class SplitterSummaryParams(typing_extensions.TypedDict):
    object: typing.Literal["splitter"]
    """
    The type of object. Will always be `"splitter"`.
    """

    id: str
    """
    The ID of the splitter.
    
    Example: `"spl_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    name: str
    """
    The name of the splitter.
    
    Example: `"Invoice Packet Splitter"`
    """

    created_at: typing_extensions.Annotated[CreatedAt, FieldMetadata(alias="createdAt")]
    updated_at: typing_extensions.Annotated[UpdatedAt, FieldMetadata(alias="updatedAt")]
