# This file was auto-generated by Fern from our API Definition.

import typing

from .legacy_fields_array_output import LegacyFieldsArrayOutput
from .legacy_json_output import LegacyJsonOutput

LegacyExtractionOutput = typing.Union[LegacyJsonOutput, LegacyFieldsArrayOutput]
