# This file was auto-generated by Fern from our API Definition.

import typing

from ..types.split_classification import SplitClassification

SplitClassificationsParams = typing.List[SplitClassification]
