# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class SplitRunsDeleteResponseParams(typing_extensions.TypedDict):
    id: str
    """
    The ID of the deleted split run
    """
