# This file was auto-generated by Fern from our API Definition.

import typing

from .legacy_classifier_output import LegacyClassifierOutputParams
from .legacy_extraction_output import LegacyExtractionOutputParams
from .legacy_splitter_output import LegacySplitterOutputParams

LegacyProcessorOutputParams = typing.Union[
    LegacyExtractionOutputParams, LegacyClassifierOutputParams, LegacySplitterOutputParams
]
