# This file was auto-generated by Fern from our API Definition.

import typing

from .conditional_extract_result import ConditionalExtractResultParams
from .conditional_extract_step_run_step import ConditionalExtractStepRunStepParams
from .step_run_base import StepRunBaseParams


class ConditionalExtractStepRunParams(StepRunBaseParams):
    step: ConditionalExtractStepRunStepParams
    result: typing.Optional[ConditionalExtractResultParams]
    """
    The result of this conditional extract step. Currently, `result` is always present for returned step runs. It is nullable to allow for future support of returning step runs with non-successful statuses.
    """
