# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.webhook_payload_format import WebhookPayloadFormat


class WebhookPayloadOptionsParams(typing_extensions.TypedDict):
    """
    Configuration for how webhook payloads are delivered.
    """

    format: WebhookPayloadFormat
    url_threshold_bytes: typing_extensions.NotRequired[
        typing_extensions.Annotated[int, FieldMetadata(alias="urlThresholdBytes")]
    ]
    """
    When `format` is `url`, payloads larger than this threshold (in bytes) are delivered as a signed download URL instead of inline JSON. Only applicable when `format` is `url`.
    """
