# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class EditRunStatus(enum.StrEnum):
    """
    The status of the edit run:
    * `"PROCESSING"` - The file is still being processed
    * `"PROCESSED"` - The file was successfully edited
    * `"FAILED"` - The editing failed (see `failureReason` for details)
    """

    PROCESSING = "PROCESSING"
    PROCESSED = "PROCESSED"
    FAILED = "FAILED"
    _UNKNOWN = "__EDITRUNSTATUS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "EditRunStatus":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        processing: typing.Callable[[], T_Result],
        processed: typing.Callable[[], T_Result],
        failed: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is EditRunStatus.PROCESSING:
            return processing()
        if self is EditRunStatus.PROCESSED:
            return processed()
        if self is EditRunStatus.FAILED:
            return failed()
        return _unknown_member(self._value_)
