# This file was auto-generated by Fern from our API Definition.

import typing

from .extract_output_json import ExtractOutputJson
from .extract_output_legacy import ExtractOutputLegacy

ExtractOutput = typing.Union[ExtractOutputJson, ExtractOutputLegacy]
