# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.created_at import CreatedAt


class ClassifierVersionSummaryParams(typing_extensions.TypedDict):
    object: typing.Literal["classifier_version"]
    """
    The type of object. Will always be `"classifier_version"`.
    """

    id: str
    """
    The unique identifier for this version of the classifier.
    
    Example: `"clv_xK9mLPqRtN3vS8wF5hB2cQ"`
    """

    description: typing.Optional[str]
    """
    A description of this version of the classifier.
    
    Example: `"Added new document types for Q4 processing"`
    """

    version: str
    """
    The version number or identifier for this specific version of the classifier. The draft version will have version="draft".
    
    Examples: `"1.0"`, `"2.1"`, `"draft"`
    """

    classifier_id: typing_extensions.Annotated[str, FieldMetadata(alias="classifierId")]
    """
    The ID of the classifier that this version belongs to.
    
    Example: `"cl_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    created_at: typing_extensions.Annotated[CreatedAt, FieldMetadata(alias="createdAt")]
