# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.run_metadata import RunMetadata
from ...types.run_secrets import RunSecrets
from .workflow_runs_create_batch_request_inputs_item_file import WorkflowRunsCreateBatchRequestInputsItemFile


class WorkflowRunsCreateBatchRequestInputsItem(UncheckedBaseModel):
    file: WorkflowRunsCreateBatchRequestInputsItemFile = pydantic.Field()
    """
    The file to be processed. Files can be provided as a URL, an Extend file ID, or raw text.
    """

    metadata: typing.Optional[RunMetadata] = None
    secrets: typing.Optional[RunSecrets] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
