# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        ProcessorCreateRequestConfig,
        ProcessorCreateRequestConfig_Classify,
        ProcessorCreateRequestConfig_Extract,
        ProcessorCreateRequestConfig_Splitter,
        ProcessorCreateResponse,
        ProcessorListRequestSortBy,
        ProcessorListRequestSortDir,
        ProcessorUpdateRequestConfig,
        ProcessorUpdateRequestConfig_Classify,
        ProcessorUpdateRequestConfig_Extract,
        ProcessorUpdateRequestConfig_Splitter,
        ProcessorUpdateResponse,
    )
    from .requests import (
        ProcessorCreateRequestConfigParams,
        ProcessorCreateRequestConfig_ClassifyParams,
        ProcessorCreateRequestConfig_ExtractParams,
        ProcessorCreateRequestConfig_SplitterParams,
        ProcessorCreateResponseParams,
        ProcessorUpdateRequestConfigParams,
        ProcessorUpdateRequestConfig_ClassifyParams,
        ProcessorUpdateRequestConfig_ExtractParams,
        ProcessorUpdateRequestConfig_SplitterParams,
        ProcessorUpdateResponseParams,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "ProcessorCreateRequestConfig": ".types",
    "ProcessorCreateRequestConfigParams": ".requests",
    "ProcessorCreateRequestConfig_Classify": ".types",
    "ProcessorCreateRequestConfig_ClassifyParams": ".requests",
    "ProcessorCreateRequestConfig_Extract": ".types",
    "ProcessorCreateRequestConfig_ExtractParams": ".requests",
    "ProcessorCreateRequestConfig_Splitter": ".types",
    "ProcessorCreateRequestConfig_SplitterParams": ".requests",
    "ProcessorCreateResponse": ".types",
    "ProcessorCreateResponseParams": ".requests",
    "ProcessorListRequestSortBy": ".types",
    "ProcessorListRequestSortDir": ".types",
    "ProcessorUpdateRequestConfig": ".types",
    "ProcessorUpdateRequestConfigParams": ".requests",
    "ProcessorUpdateRequestConfig_Classify": ".types",
    "ProcessorUpdateRequestConfig_ClassifyParams": ".requests",
    "ProcessorUpdateRequestConfig_Extract": ".types",
    "ProcessorUpdateRequestConfig_ExtractParams": ".requests",
    "ProcessorUpdateRequestConfig_Splitter": ".types",
    "ProcessorUpdateRequestConfig_SplitterParams": ".requests",
    "ProcessorUpdateResponse": ".types",
    "ProcessorUpdateResponseParams": ".requests",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ProcessorCreateRequestConfig",
    "ProcessorCreateRequestConfigParams",
    "ProcessorCreateRequestConfig_Classify",
    "ProcessorCreateRequestConfig_ClassifyParams",
    "ProcessorCreateRequestConfig_Extract",
    "ProcessorCreateRequestConfig_ExtractParams",
    "ProcessorCreateRequestConfig_Splitter",
    "ProcessorCreateRequestConfig_SplitterParams",
    "ProcessorCreateResponse",
    "ProcessorCreateResponseParams",
    "ProcessorListRequestSortBy",
    "ProcessorListRequestSortDir",
    "ProcessorUpdateRequestConfig",
    "ProcessorUpdateRequestConfigParams",
    "ProcessorUpdateRequestConfig_Classify",
    "ProcessorUpdateRequestConfig_ClassifyParams",
    "ProcessorUpdateRequestConfig_Extract",
    "ProcessorUpdateRequestConfig_ExtractParams",
    "ProcessorUpdateRequestConfig_Splitter",
    "ProcessorUpdateRequestConfig_SplitterParams",
    "ProcessorUpdateResponse",
    "ProcessorUpdateResponseParams",
]
