# This file was auto-generated by Fern from our API Definition.

import typing

from .file_from_id import FileFromIdParams
from .file_from_text import FileFromTextParams
from .file_from_url import FileFromUrlParams

ExtractRequestFileParams = typing.Union[FileFromUrlParams, FileFromIdParams, FileFromTextParams]
