# This file was auto-generated by Fern from our API Definition.

import typing

from .file_from_id import FileFromId
from .file_from_text import FileFromText
from .file_from_url import FileFromUrl

ClassifyRequestFile = typing.Union[FileFromUrl, FileFromId, FileFromText]
