# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.figure_details_figure_type import FigureDetailsFigureType


class FigureDetailsParams(typing_extensions.TypedDict):
    """
    Details for figure blocks
    """

    type: typing.Literal["figure_details"]
    """
    Indicates this is a figure details object
    """

    image_url: typing_extensions.NotRequired[typing_extensions.Annotated[str, FieldMetadata(alias="imageUrl")]]
    """
    URL to the clipped/segmented figure image. Only set if the option `figureImageClippingEnabled` in the input is `true`, which it is by default.
    """

    figure_type: typing_extensions.NotRequired[
        typing_extensions.Annotated[FigureDetailsFigureType, FieldMetadata(alias="figureType")]
    ]
    """
    The refined type of figure - only set when figure classification and summarization is enabled. Possible values:
    
    * `image`: A photographic image
    * `chart`: A data chart or graph
    * `diagram`: A schematic or diagram
    * `logo`: A company or brand logo
    * `other`: Any other type of figure
    """
