# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class FileFromUrlParams(typing_extensions.TypedDict):
    url: str
    """
    A URL to download the file. For production use cases, we recommend using presigned URLs with a 5-15 minute expiration time.
    
    Supported file types can be found [here](https://docs.extend.ai/2026-02-09/product/general/supported-file-types).
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of the file. If not set, the file name is taken from the URL.
    """
