# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class EditObjectJson(UncheckedBaseModel):
    """
    Schema definition for an object field in a PDF edit schema. Used for signature fields and as items schema for arrays/tables.
    """

    type: typing.Optional[typing.Literal["object"]] = pydantic.Field(default=None)
    """
    Must be "object" for object schemas
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Description of the field
    """

    extend_edit_field_type: typing_extensions.Annotated[
        typing.Optional[typing.Literal["signature"]], FieldMetadata(alias="extend_edit:field_type")
    ] = pydantic.Field(alias="extend_edit:field_type", default=None)
    """
    The PDF field type. For object schemas, must be "signature".
    """

    properties: typing.Optional[typing.Dict[str, "EditJson"]] = pydantic.Field(default=None)
    """
    Nested properties. Each property follows the EditJSON structure.
    """

    required: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of required property names
    """

    additional_properties: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="additionalProperties")
    ] = pydantic.Field(alias="additionalProperties", default=None)
    """
    Whether additional properties are allowed
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .edit_json import EditJson  # noqa: E402, I001

update_forward_refs(EditObjectJson, EditJson=EditJson)
