# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from .legacy_splitter_output_splits_item import LegacySplitterOutputSplitsItemParams


class LegacySplitterOutputParams(typing_extensions.TypedDict):
    splits: typing.Sequence[LegacySplitterOutputSplitsItemParams]
    is_external: typing_extensions.NotRequired[typing_extensions.Annotated[bool, FieldMetadata(alias="isExternal")]]
