# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from .parse_run import ParseRunParams


class ParseResultParams(typing_extensions.TypedDict):
    """
    The result of a parse step.
    """

    parse_run: typing_extensions.Annotated[ParseRunParams, FieldMetadata(alias="parseRun")]
    """
    The parse run that was executed.
    """
