# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from .bounding_box import BoundingBoxParams


class ParseRunOutputOcrWordsItemParams(typing_extensions.TypedDict):
    content: str
    """
    The text content of the word.
    """

    bounding_box: typing_extensions.Annotated[BoundingBoxParams, FieldMetadata(alias="boundingBox")]
    """
    The bounding box coordinates of the word.
    """

    confidence: float
    """
    The confidence score of the OCR detection for this word, between 0 and 1.
    """

    page_number: typing_extensions.Annotated[float, FieldMetadata(alias="pageNumber")]
    """
    The page number where the word was detected.
    """
