# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from .legacy_list_processors_processor import LegacyListProcessorsProcessorParams


class LegacyListProcessorsResponseParams(typing_extensions.TypedDict):
    success: bool
    """
    Indicates the request was successful
    """

    warning: typing_extensions.NotRequired[typing.Optional[str]]
    """
    Optional warning message
    """

    processors: typing.Sequence[LegacyListProcessorsProcessorParams]
    """
    Array of processors
    """

    next_page_token: typing_extensions.NotRequired[
        typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="nextPageToken")]
    ]
    """
    Token for retrieving the next page of results. Will be null if there are no more results.
    """
