# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata


class EditTextOptionsParams(typing_extensions.TypedDict):
    """
    Text styling options for text fields
    """

    font_size: typing_extensions.NotRequired[typing_extensions.Annotated[float, FieldMetadata(alias="fontSize")]]
    """
    Font size in points
    """

    font_color: typing_extensions.NotRequired[
        typing_extensions.Annotated[typing.Sequence[float], FieldMetadata(alias="fontColor")]
    ]
    """
    RGB color values (0-255) for text color
    """

    font: typing_extensions.NotRequired[str]
    """
    Font family name
    """

    combing: typing_extensions.NotRequired[bool]
    """
    Whether this is a combed field (like SSN fields with individual character boxes)
    """

    max_length: typing_extensions.NotRequired[typing_extensions.Annotated[int, FieldMetadata(alias="maxLength")]]
    """
    Maximum number of characters allowed
    """
