# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from .citation_page import CitationPageParams
from .polygon import PolygonParams


class CitationParams(typing_extensions.TypedDict):
    page: typing_extensions.NotRequired[CitationPageParams]
    reference_text: typing_extensions.NotRequired[
        typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="referenceText")]
    ]
    """
    The text that was referenced
    """

    polygon: typing_extensions.NotRequired[typing.Sequence[PolygonParams]]
    """
    Array of points defining the polygon around the referenced text
    """
