# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .parse_run_output_ocr_words_item import ParseRunOutputOcrWordsItemParams


class ParseRunOutputOcrParams(typing_extensions.TypedDict):
    """
    Raw OCR data from the parsing process. Only included when `returnOcr` is configured in the parse config's advanced options.
    """

    words: typing_extensions.NotRequired[typing.Sequence[ParseRunOutputOcrWordsItemParams]]
    """
    An array of individual words detected by OCR.
    """
