# This file was auto-generated by Fern from our API Definition.

import typing

from ..types.legacy_provided_extraction_field_result import LegacyProvidedExtractionFieldResult

LegacyProvidedFieldsArrayOutputParams = typing.Dict[str, LegacyProvidedExtractionFieldResult]
