# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class LegacyExtendErrorParams(typing_extensions.TypedDict):
    code: str
    """
    Error code identifying the type of error
    """

    message: str
    """
    Human-readable error message
    """

    request_id: typing_extensions.Annotated[str, FieldMetadata(alias="requestId")]
    """
    Unique request identifier for support purposes
    """

    retryable: bool
    """
    Whether the request can be retried
    """
