# This file was auto-generated by Fern from our API Definition.

import typing

from .merge_extract_result import MergeExtractResultParams
from .merge_extract_step_run_step import MergeExtractStepRunStepParams
from .step_run_base import StepRunBaseParams


class MergeExtractStepRunParams(StepRunBaseParams):
    step: MergeExtractStepRunStepParams
    result: typing.Optional[MergeExtractResultParams]
    """
    The result of this merge extract step. Currently, `result` is always present for returned step runs. It is nullable to allow for future support of returning step runs with non-successful statuses.
    """
