# This file was auto-generated by Fern from our API Definition.

import typing

from .rule_validation_result import RuleValidationResultParams
from .rule_validation_step_run_step import RuleValidationStepRunStepParams
from .step_run_base import StepRunBaseParams


class RuleValidationStepRunParams(StepRunBaseParams):
    step: RuleValidationStepRunStepParams
    result: typing.Optional[RuleValidationResultParams]
    """
    The result of this rule validation step. Currently, `result` is always present for returned step runs. It is nullable to allow for future support of returning step runs with non-successful statuses.
    """
