# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .webhook_payload_format import WebhookPayloadFormat


class WebhookPayloadOptions(UncheckedBaseModel):
    """
    Configuration for how webhook payloads are delivered.
    """

    format: WebhookPayloadFormat
    url_threshold_bytes: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="urlThresholdBytes")] = (
        pydantic.Field(alias="urlThresholdBytes", default=None)
    )
    """
    When `format` is `url`, payloads larger than this threshold (in bytes) are delivered as a signed download URL instead of inline JSON. Only applicable when `format` is `url`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
