# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from .file_summary import FileSummaryParams
from .provided_processor_output import ProvidedProcessorOutputParams


class EvaluationSetItemParams(typing_extensions.TypedDict):
    object: typing.Literal["evaluation_set_item"]
    """
    The type of object. In this case, it will always be `"evaluation_set_item"`.
    """

    id: str
    """
    The ID of the evaluation set item.
    
    Example: `"evi_kR9mNP12Qw4yTv8BdR3H"`
    """

    evaluation_set_id: typing_extensions.Annotated[str, FieldMetadata(alias="evaluationSetId")]
    """
    The ID of the evaluation set that this item belongs to.
    
    Example: `"ev_2LcgeY_mp2T5yPaEuq5Lw"`
    """

    file: FileSummaryParams
    """
    A summary of the file associated with the evaluation set item.
    """

    expected_output: typing_extensions.Annotated[ProvidedProcessorOutputParams, FieldMetadata(alias="expectedOutput")]
    """
    The expected output that will be used to evaluate the performance of the extractor, classifier, or splitter associated with the evaluation set. This must conform to the output schema of the entity associated with the evaluation set.
    """
