# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from .edit_run_output_edited_file import EditRunOutputEditedFileParams


class EditRunOutputParams(typing_extensions.TypedDict):
    """
    The output of the edit run.

    **Availability:** Present when `status` is `"PROCESSED"`.
    """

    edited_file: typing_extensions.Annotated[EditRunOutputEditedFileParams, FieldMetadata(alias="editedFile")]
    """
    Information about the edited output file.
    """

    filled_values: typing_extensions.NotRequired[
        typing_extensions.Annotated[typing.Dict[str, typing.Any], FieldMetadata(alias="filledValues")]
    ]
    """
    The field values that were filled into the document. Keys correspond to the property names in the schema. Will not be present if no values were filled.
    """
