# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class LegacyListProcessorsProcessorVersionParams(typing_extensions.TypedDict):
    id: str
    """
    The unique identifier for this version of the document processor.
    
    Example: `"exv_xK9mLPqRtN3vS8wF5hB2cQ"`
    """

    version: str
    """
    The version number or identifier for this processor version.
    
    Example: `"3"`
    """
