# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata


class LegacyExtractionOutputEditsParams(typing_extensions.TypedDict):
    """
    A record of edits made to the processor output.
    """

    original_value: typing_extensions.NotRequired[
        typing_extensions.Annotated[typing.Any, FieldMetadata(alias="originalValue")]
    ]
    """
    The original value before editing.
    """

    edited_value: typing_extensions.NotRequired[
        typing_extensions.Annotated[typing.Any, FieldMetadata(alias="editedValue")]
    ]
    """
    The value after editing.
    """

    notes: typing_extensions.NotRequired[str]
    """
    Any notes added during editing.
    """

    page: typing_extensions.NotRequired[float]
    """
    The page number where the edit was made.
    """

    field_type: typing_extensions.NotRequired[typing_extensions.Annotated[str, FieldMetadata(alias="fieldType")]]
    """
    The type of the edited field.
    """
