# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class EditTextOptions(UncheckedBaseModel):
    """
    Text styling options for text fields
    """

    font_size: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="fontSize")] = pydantic.Field(
        alias="fontSize", default=None
    )
    """
    Font size in points
    """

    font_color: typing_extensions.Annotated[typing.Optional[typing.List[float]], FieldMetadata(alias="fontColor")] = (
        pydantic.Field(alias="fontColor", default=None)
    )
    """
    RGB color values (0-255) for text color
    """

    font: typing.Optional[str] = pydantic.Field(default=None)
    """
    Font family name
    """

    combing: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether this is a combed field (like SSN fields with individual character boxes)
    """

    max_length: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="maxLength")] = pydantic.Field(
        alias="maxLength", default=None
    )
    """
    Maximum number of characters allowed
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
