# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .webhook_payload_options import WebhookPayloadOptionsParams


class WebhookAdvancedOptionsParams(typing_extensions.TypedDict):
    """
    Advanced configuration options for the webhook endpoint, including custom headers and payload delivery settings.
    """

    headers: typing_extensions.NotRequired[typing.Dict[str, str]]
    """
    Custom HTTP headers to include in webhook requests.
    """

    payload: typing_extensions.NotRequired[WebhookPayloadOptionsParams]
