# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .extract_run import ExtractRun


class ConditionalExtractResult(UncheckedBaseModel):
    """
    The result of a conditional extract step, which routes to different extractors based on rules.
    """

    extract_run: typing_extensions.Annotated[ExtractRun, FieldMetadata(alias="extractRun")] = pydantic.Field(
        alias="extractRun"
    )
    """
    The extract run that was executed based on the matched rule.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(ConditionalExtractResult)
