# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class PageRangesItemParams(typing_extensions.TypedDict):
    start: int
    """
    The start page of the range.
    """

    end: int
    """
    The end page of the range.
    """
