# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class ExtractAdvancedOptionsArrayCitationStrategy(enum.StrEnum):
    """
    Granularity for array citations. This requires citationsEnabled=true and a base processor version that supports property-level array citations (extraction_performance ≥ 4.4.0).
    """

    ITEM = "item"
    PROPERTY = "property"
    _UNKNOWN = "__EXTRACTADVANCEDOPTIONSARRAYCITATIONSTRATEGY_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ExtractAdvancedOptionsArrayCitationStrategy":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        item: typing.Callable[[], T_Result],
        property: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ExtractAdvancedOptionsArrayCitationStrategy.ITEM:
            return item()
        if self is ExtractAdvancedOptionsArrayCitationStrategy.PROPERTY:
            return property()
        return _unknown_member(self._value_)
