# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class ReleaseType(enum.StrEnum):
    """
    The type of release for this version. The two options are "major" and "minor", which will increment the version number accordingly.
    """

    MAJOR = "major"
    MINOR = "minor"
    _UNKNOWN = "__RELEASETYPE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ReleaseType":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        major: typing.Callable[[], T_Result],
        minor: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ReleaseType.MAJOR:
            return major()
        if self is ReleaseType.MINOR:
            return minor()
        return _unknown_member(self._value_)
