# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from .legacy_json_output_metadata_value_citations_item_polygon_item import (
    LegacyJsonOutputMetadataValueCitationsItemPolygonItemParams,
)


class LegacyJsonOutputMetadataValueCitationsItemParams(typing_extensions.TypedDict):
    page: typing_extensions.NotRequired[float]
    """
    Page number where the citation was found
    """

    reference_text: typing_extensions.NotRequired[
        typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="referenceText")]
    ]
    """
    The text that was referenced
    """

    polygon: typing_extensions.NotRequired[typing.Sequence[LegacyJsonOutputMetadataValueCitationsItemPolygonItemParams]]
    """
    Array of points defining the polygon around the referenced text
    """

    page_width: typing_extensions.NotRequired[typing_extensions.Annotated[float, FieldMetadata(alias="pageWidth")]]
    """
    Width of the page in points
    """

    page_height: typing_extensions.NotRequired[typing_extensions.Annotated[float, FieldMetadata(alias="pageHeight")]]
    """
    Height of the page in points
    """
