# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata


class EvaluationSetRunOptionsParams(typing_extensions.TypedDict):
    """
    The options for the evaluation set run.
    """

    fuzzy_match_fields: typing_extensions.NotRequired[
        typing_extensions.Annotated[typing.Sequence[str], FieldMetadata(alias="fuzzyMatchFields")]
    ]
    """
    The fields that were fuzzy matched.
    """

    exclude_fields: typing_extensions.NotRequired[
        typing_extensions.Annotated[typing.Sequence[str], FieldMetadata(alias="excludeFields")]
    ]
    """
    The fields that were excluded from the run.
    """
