# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ...core.serialization import FieldMetadata
from ...requests.evaluation_set_item import EvaluationSetItemParams


class EvaluationSetItemsCreateResponseParams(typing_extensions.TypedDict):
    evaluation_set_items: typing_extensions.Annotated[
        typing.Sequence[EvaluationSetItemParams], FieldMetadata(alias="evaluationSetItems")
    ]
