# This file was auto-generated by Fern from our API Definition.

import typing

from .split_result import SplitResultParams
from .split_step_run_step import SplitStepRunStepParams
from .step_run_base import StepRunBaseParams


class SplitStepRunParams(StepRunBaseParams):
    step: SplitStepRunStepParams
    result: typing.Optional[SplitResultParams]
    """
    The result of this split step. Currently, `result` is always present for returned step runs. It is nullable to allow for future support of returning step runs with non-successful statuses.
    """
