# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...core.serialization import FieldMetadata
from ...requests.provided_processor_output import ProvidedProcessorOutputParams


class WorkflowRunsCreateRequestOutputsItemParams(typing_extensions.TypedDict):
    processor_id: typing_extensions.Annotated[str, FieldMetadata(alias="processorId")]
    """
    The ID of the extractor, classifier, or splitter that the output is associated with.
    Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    output: ProvidedProcessorOutputParams
    """
    The output to be used for the workflow run. The structure will depend on the processor type. More details can be found on the "output type" page for the corresponding processor, in the guides section.
    """
