# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .workflow_step_base import WorkflowStepBaseParams


class SplitStepRunStepParams(WorkflowStepBaseParams):
    type: typing_extensions.NotRequired[typing.Literal["SPLIT"]]
    """
    The type of workflow step. Will always be `"SPLIT"` for this step run type.
    """
