# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .parse_config_block_options_figures import ParseConfigBlockOptionsFiguresParams
from .parse_config_block_options_tables import ParseConfigBlockOptionsTablesParams
from .parse_config_block_options_text import ParseConfigBlockOptionsTextParams


class ParseConfigBlockOptionsParams(typing_extensions.TypedDict):
    """
    Options for controlling how different block types are processed.
    """

    figures: typing_extensions.NotRequired[ParseConfigBlockOptionsFiguresParams]
    """
    Options for figure blocks.
    """

    tables: typing_extensions.NotRequired[ParseConfigBlockOptionsTablesParams]
    """
    Options for table blocks.
    """

    text: typing_extensions.NotRequired[ParseConfigBlockOptionsTextParams]
    """
    Options for text blocks.
    """
