# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        ProcessorVersionCreateRequestConfig,
        ProcessorVersionCreateRequestConfig_Classify,
        ProcessorVersionCreateRequestConfig_Extract,
        ProcessorVersionCreateRequestConfig_Splitter,
        ProcessorVersionCreateRequestReleaseType,
        ProcessorVersionCreateResponse,
        ProcessorVersionGetResponse,
        ProcessorVersionListResponse,
    )
    from .requests import (
        ProcessorVersionCreateRequestConfigParams,
        ProcessorVersionCreateRequestConfig_ClassifyParams,
        ProcessorVersionCreateRequestConfig_ExtractParams,
        ProcessorVersionCreateRequestConfig_SplitterParams,
        ProcessorVersionCreateResponseParams,
        ProcessorVersionGetResponseParams,
        ProcessorVersionListResponseParams,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "ProcessorVersionCreateRequestConfig": ".types",
    "ProcessorVersionCreateRequestConfigParams": ".requests",
    "ProcessorVersionCreateRequestConfig_Classify": ".types",
    "ProcessorVersionCreateRequestConfig_ClassifyParams": ".requests",
    "ProcessorVersionCreateRequestConfig_Extract": ".types",
    "ProcessorVersionCreateRequestConfig_ExtractParams": ".requests",
    "ProcessorVersionCreateRequestConfig_Splitter": ".types",
    "ProcessorVersionCreateRequestConfig_SplitterParams": ".requests",
    "ProcessorVersionCreateRequestReleaseType": ".types",
    "ProcessorVersionCreateResponse": ".types",
    "ProcessorVersionCreateResponseParams": ".requests",
    "ProcessorVersionGetResponse": ".types",
    "ProcessorVersionGetResponseParams": ".requests",
    "ProcessorVersionListResponse": ".types",
    "ProcessorVersionListResponseParams": ".requests",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ProcessorVersionCreateRequestConfig",
    "ProcessorVersionCreateRequestConfigParams",
    "ProcessorVersionCreateRequestConfig_Classify",
    "ProcessorVersionCreateRequestConfig_ClassifyParams",
    "ProcessorVersionCreateRequestConfig_Extract",
    "ProcessorVersionCreateRequestConfig_ExtractParams",
    "ProcessorVersionCreateRequestConfig_Splitter",
    "ProcessorVersionCreateRequestConfig_SplitterParams",
    "ProcessorVersionCreateRequestReleaseType",
    "ProcessorVersionCreateResponse",
    "ProcessorVersionCreateResponseParams",
    "ProcessorVersionGetResponse",
    "ProcessorVersionGetResponseParams",
    "ProcessorVersionListResponse",
    "ProcessorVersionListResponseParams",
]
