# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class SplitAdvancedOptionsSplitMethod(enum.StrEnum):
    """
    The method to use for splitting documents. `high_precision` is more accurate but slower, while `basic_precision` is faster but less precise.

    **Deprecated:** For `splitting_light` >= 1.3.0 and `splitting_performance` >= 1.5.0, this field has no impact and is ignored if provided. It is still accepted for compatibility with older integrations.
    """

    HIGH_PRECISION = "high_precision"
    BASIC_PRECISION = "basic_precision"
    _UNKNOWN = "__SPLITADVANCEDOPTIONSSPLITMETHOD_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "SplitAdvancedOptionsSplitMethod":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        high_precision: typing.Callable[[], T_Result],
        basic_precision: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is SplitAdvancedOptionsSplitMethod.HIGH_PRECISION:
            return high_precision()
        if self is SplitAdvancedOptionsSplitMethod.BASIC_PRECISION:
            return basic_precision()
        return _unknown_member(self._value_)
