# This file was auto-generated by Fern from our API Definition.

import typing

from .classify_step_run import ClassifyStepRun
from .conditional_extract_step_run import ConditionalExtractStepRun
from .external_data_validation_step_run import ExternalDataValidationStepRun
from .extract_step_run import ExtractStepRun
from .merge_extract_step_run import MergeExtractStepRun
from .parse_step_run import ParseStepRun
from .rule_validation_step_run import RuleValidationStepRun
from .split_step_run import SplitStepRun

StepRun = typing.Union[
    ParseStepRun,
    ExtractStepRun,
    ClassifyStepRun,
    SplitStepRun,
    MergeExtractStepRun,
    ConditionalExtractStepRun,
    RuleValidationStepRun,
    ExternalDataValidationStepRun,
]
