# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...core.serialization import FieldMetadata


class ProcessorRunDeleteResponseParams(typing_extensions.TypedDict):
    success: bool
    document_processor_run_id: typing_extensions.Annotated[str, FieldMetadata(alias="documentProcessorRunId")]
    """
    The ID of the deleted processor run
    """

    message: str
    """
    Confirmation message
    """
