# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .file_summary import FileSummary


class EvaluationSetItemSummary(UncheckedBaseModel):
    object: typing.Literal["evaluation_set_item"] = pydantic.Field(default="evaluation_set_item")
    """
    The type of object. In this case, it will always be `"evaluation_set_item"`.
    """

    id: str = pydantic.Field()
    """
    The ID of the evaluation set item.
    
    Example: `"evi_kR9mNP12Qw4yTv8BdR3H"`
    """

    file: FileSummary = pydantic.Field()
    """
    A summary of the file associated with the evaluation set item.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
