# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.batch_run_status import BatchRunStatus
from ..types.created_at import CreatedAt
from ..types.updated_at import UpdatedAt
from .batch_run_entity import BatchRunEntityParams
from .batch_run_entity_version import BatchRunEntityVersionParams
from .batch_run_metrics import BatchRunMetricsParams


class BatchRunParams(typing_extensions.TypedDict):
    object: typing.Literal["batch_run"]
    """
    The type of object. In this case, it will always be `"batch_run"`.
    """

    id: str
    """
    The unique identifier for this batch run.
    
    Example: `"batch_run_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    entity: typing.Optional[BatchRunEntityParams]
    """
    The extractor, classifier, or splitter that was run.
    
    **Availability:** Present when an entity was provided when creating the batch run.
    """

    entity_version: typing_extensions.Annotated[
        typing.Optional[BatchRunEntityVersionParams], FieldMetadata(alias="entityVersion")
    ]
    """
    The version of the extractor, classifier, or splitter that was run.
    
    **Availability:** Present when an entity was provided when creating the batch run.
    """

    status: BatchRunStatus
    metrics: BatchRunMetricsParams
    created_at: typing_extensions.Annotated[CreatedAt, FieldMetadata(alias="createdAt")]
    updated_at: typing_extensions.Annotated[UpdatedAt, FieldMetadata(alias="updatedAt")]
