# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.json_object import JsonObject
from .extract_output_metadata import ExtractOutputMetadataParams


class ExtractOutputJsonParams(typing_extensions.TypedDict):
    value: JsonObject
    """
    The extracted values conforming to the schema defined in the processor config
    """

    metadata: ExtractOutputMetadataParams
