# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class EditRunMetricsParams(typing_extensions.TypedDict):
    """
    Metrics about the editing process.

    **Availability:** Present when `status` is `"PROCESSED"`.
    """

    processing_time_ms: typing_extensions.Annotated[float, FieldMetadata(alias="processingTimeMs")]
    """
    Total processing time in milliseconds.
    """

    page_count: typing_extensions.Annotated[int, FieldMetadata(alias="pageCount")]
    """
    The number of pages in the document.
    """

    field_count: typing_extensions.Annotated[int, FieldMetadata(alias="fieldCount")]
    """
    The total number of fields in the schema.
    """

    fields_detected_count: typing_extensions.Annotated[int, FieldMetadata(alias="fieldsDetectedCount")]
    """
    The number of fields that were automatically detected.
    """

    fields_annotated_count: typing_extensions.Annotated[int, FieldMetadata(alias="fieldsAnnotatedCount")]
    """
    The number of fields that were annotated with bounding boxes.
    """

    field_detection_time_ms: typing_extensions.Annotated[float, FieldMetadata(alias="fieldDetectionTimeMs")]
    """
    The time taken to detect fields in the document, in milliseconds.
    """

    field_annotation_time_ms: typing_extensions.Annotated[float, FieldMetadata(alias="fieldAnnotationTimeMs")]
    """
    The time taken to annotate field positions in the document, in milliseconds.
    """

    field_filling_time_ms: typing_extensions.Annotated[float, FieldMetadata(alias="fieldFillingTimeMs")]
    """
    The time taken to fill the fields in the document, in milliseconds.
    """
