# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.created_at import CreatedAt
from ..types.file_type import FileType
from ..types.updated_at import UpdatedAt
from .file_metadata import FileMetadataParams


class FileSummaryParams(typing_extensions.TypedDict):
    object: typing.Literal["file"]
    """
    The type of object. Will always be `"file"`.
    """

    id: str
    """
    ID for the file.
    
    Example: `"file_xK9mLPqRtN3vS8wF5hB2cQ"`
    """

    name: str
    """
    The name of the file
    
    Example: `"Invoices.pdf"`
    """

    type: typing.Optional[FileType]
    """
    The type of the file.
    
    **Availability:** Present when the file type could be determined.
    """

    parent_file_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="parentFileId")]
    """
    ID of the parent file.
    
    **Availability:** Present for files created via a Splitter in a workflow.
    """

    metadata: FileMetadataParams
    created_at: typing_extensions.Annotated[CreatedAt, FieldMetadata(alias="createdAt")]
    updated_at: typing_extensions.Annotated[UpdatedAt, FieldMetadata(alias="updatedAt")]
