# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class EditConfigAdvancedOptionsParams(typing_extensions.TypedDict):
    """
    Advanced options for the edit operation.
    """

    table_parsing_enabled: typing_extensions.NotRequired[
        typing_extensions.Annotated[bool, FieldMetadata(alias="tableParsingEnabled")]
    ]
    """
    Whether to parse table regions as arrays of objects. Defaults to `false`.
    """

    flatten_pdf: typing_extensions.NotRequired[typing_extensions.Annotated[bool, FieldMetadata(alias="flattenPdf")]]
    """
    Whether to flatten the PDF (form widgets will not be editable with a PDF edit). Defaults to `true`.
    """

    radio_enums_enabled: typing_extensions.NotRequired[
        typing_extensions.Annotated[bool, FieldMetadata(alias="radioEnumsEnabled")]
    ]
    """
    Whether to model radio fields as enums. This ensures only one radio widget is filled. Defaults to false.
    """

    native_fields_only: typing_extensions.NotRequired[
        typing_extensions.Annotated[bool, FieldMetadata(alias="nativeFieldsOnly")]
    ]
    """
    If enabled, only native AcroForm from the PDF will be imported and used in the schema (skips object detection). Defaults to false.
    """
