# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class ExtractAdvancedOptionsExcelSheetSelectionStrategy(enum.StrEnum):
    """
    Strategy for selecting sheets from Excel documents.
    """

    INTELLIGENT = "intelligent"
    ALL = "all"
    FIRST = "first"
    LAST = "last"
    _UNKNOWN = "__EXTRACTADVANCEDOPTIONSEXCELSHEETSELECTIONSTRATEGY_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ExtractAdvancedOptionsExcelSheetSelectionStrategy":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        intelligent: typing.Callable[[], T_Result],
        all_: typing.Callable[[], T_Result],
        first: typing.Callable[[], T_Result],
        last: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ExtractAdvancedOptionsExcelSheetSelectionStrategy.INTELLIGENT:
            return intelligent()
        if self is ExtractAdvancedOptionsExcelSheetSelectionStrategy.ALL:
            return all_()
        if self is ExtractAdvancedOptionsExcelSheetSelectionStrategy.FIRST:
            return first()
        if self is ExtractAdvancedOptionsExcelSheetSelectionStrategy.LAST:
            return last()
        return _unknown_member(self._value_)
