# This file was auto-generated by Fern from our API Definition.

import typing

from .extract_config_json import ExtractConfigJsonParams
from .extract_config_legacy import ExtractConfigLegacyParams

ExtractConfigParams = typing.Union[ExtractConfigJsonParams, ExtractConfigLegacyParams]
