# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.parse_config_chunking_strategy_type import ParseConfigChunkingStrategyType
from .parse_config_chunking_strategy_options import ParseConfigChunkingStrategyOptionsParams


class ParseConfigChunkingStrategyParams(typing_extensions.TypedDict):
    """
    Strategy for dividing the document into chunks.
    """

    type: typing_extensions.NotRequired[ParseConfigChunkingStrategyType]
    """
    The type of chunking strategy. Supported values:
    
    * `page`: Chunk document by pages.
    * `document`: Entire document is a single chunk. Essentially no chunking.
    * `section`: Split by logical sections. Not supported for target=spatial.
    """

    options: typing_extensions.NotRequired[ParseConfigChunkingStrategyOptionsParams]
    """
    Additional options for the chunking strategy.
    """
