# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .external_data_validation_result_response import ExternalDataValidationResultResponseParams


class ExternalDataValidationResultParams(typing_extensions.TypedDict):
    """
    The result of an external data validation step.
    """

    response: ExternalDataValidationResultResponseParams
    """
    The response from the external validation endpoint.
    """
