# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from .classify_run import ClassifyRunParams


class ClassifyResultParams(typing_extensions.TypedDict):
    """
    The result of a classify step.
    """

    classify_run: typing_extensions.Annotated[ClassifyRunParams, FieldMetadata(alias="classifyRun")]
    """
    The classify run that was executed.
    """
