# This file was auto-generated by Fern from our API Definition.

import typing

from .extract_result import ExtractResultParams
from .extract_step_run_step import ExtractStepRunStepParams
from .step_run_base import StepRunBaseParams


class ExtractStepRunParams(StepRunBaseParams):
    step: ExtractStepRunStepParams
    result: typing.Optional[ExtractResultParams]
    """
    The result of this extract step. Currently, `result` is always present for returned step runs. It is nullable to allow for future support of returning step runs with non-successful statuses.
    """
